Installation
============

Dependencies
------------

.. include:: requirements.rst

Installation using pip
----------------------

The easiest way to install guidata is using `pip <https://pip.pypa.io>`_::

    pip install guidata

Installation from source
------------------------

To install from source, clone the repository or download the source package
from `PyPI <https://pypi.org/project/guidata/>`_.

Then run the following command (using `build <https://pypi.org/project/build/>`_)::

    python -m build
